.. |space| unicode:: 0xA0
.. |tab| replace:: |space| |space| |space| |space|

.. comment BEGIN_LATEX_MACROS
   These latex macros must also be defined in latex_elements in conf.py

.. rst-class:: hidden

   :math:`\newcommand{\B}[1]{ {\bf #1} }`
   :math:`\newcommand{\R}[1]{ {\rm #1} }`

.. comment END_LATEX_MACROS
